<?php

namespace App\Http\Controllers;

use App\Models\Project;
use App\Models\User;
use Illuminate\Http\Request;

class ProjectController extends Controller
{
    public function index()
    {
        $projects = Project::with('creator')->get(); 
        $users = User::all(); 

        return view('admin.projects', compact('projects', 'users'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'slug' => 'required|string|max:255|unique:projects',
            'description' => 'required|string',
            'start_date' => 'required|date',
            'end_date' => 'required|date|after_or_equal:start_date',
            'created_by' => 'required|exists:users,id',
        ]);

        Project::create($validated);

        return redirect()->route('admin.projects')->with('success', 'Project created successfully.');
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'slug' => 'required|string|max:255|unique:projects,slug,' . $id,
            'description' => 'required|string',
            'start_date' => 'required|date',
            'end_date' => 'required|date|after_or_equal:start_date',
            'created_by' => 'required|exists:users,id',
        ]);

        $project = Project::findOrFail($id);
        $project->update($request->only([
            'name', 'slug', 'description', 'start_date', 'end_date', 'created_by'
        ]));

        return redirect()->back()->with('success', 'Project updated successfully.');
    }

    public function delete($id)
    {
        $project = Project::findOrFail($id);
        $project->delete();

        return redirect()->back()->with('success', 'Project deleted successfully.');
    }
}

