<x-app-layout>
    <x-slot name="header">Project Management Page</x-slot>

    <div class="projects-container">
        <h1>Project List</h1>

        <div class="action-bar">
            <button onclick="document.getElementById('createForm').classList.toggle('hidden')" class="create-button">
                + Create New Project
            </button>
        </div>

        <div id="createForm" class="form-section hidden">
            <form action="{{ route('admin.projects.store') }}" method="POST">
                @csrf
                <div class="form-grid">
                    <div class="form-group">
                        <label>Name</label>
                        <input type="text" name="name" required>
                    </div>
                    <div class="form-group">
                        <label>Slug</label>
                        <input type="text" name="slug" required>
                    </div>
                    <div class="form-group full-width">
                        <label>Description</label>
                        <textarea name="description" rows="3" required></textarea>
                    </div>
                    <div class="form-group">
                        <label>Start Date</label>
                        <input type="datetime-local" name="start_date" required>
                    </div>
                    <div class="form-group">
                        <label>End Date</label>
                        <input type="datetime-local" name="end_date" required>
                    </div>
                    <div class="form-group">
                        <label>Created By</label>
                        <select name="created_by" required>
                            @foreach($users as $user)
                                <option value="{{ $user->id }}">{{ $user->name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <button type="submit" class="submit-button">Create Project</button>
            </form>
        </div>

        <table class="project-table">
    <thead>
        <tr>
            <th>ID</th>
            <th>Name</th>
            <th>Slug</th>
            <th>Description</th>
            <th>Start Date</th>
            <th>End Date</th>
            <th>Created By</th>
            <th>Actions</th>
        </tr>
    </thead>
    <tbody>
        @foreach ($projects as $project)
        <tr>
            <form id="form-{{ $project->id }}" action="{{ route('admin.projects.update', $project->id) }}" method="POST">
                @csrf
                @method('PUT')
                <td>{{ $project->id }}</td>

                <td>
                    <span class="display-only" id="name-label-{{ $project->id }}">{{ $project->name }}</span>
                    <input type="text" name="name" value="{{ $project->name }}" class="edit-only hidden" id="name-input-{{ $project->id }}">
                </td>

                <td>
                    <span class="display-only" id="slug-label-{{ $project->id }}">{{ $project->slug }}</span>
                    <input type="text" name="slug" value="{{ $project->slug }}" class="edit-only hidden" id="slug-input-{{ $project->id }}">
                </td>

                <td>
                    <span class="display-only" id="desc-label-{{ $project->id }}">{{ Str::limit($project->description, 50) }}</span>
                    <textarea name="description" rows="2" class="edit-only hidden" id="desc-input-{{ $project->id }}">{{ $project->description }}</textarea>
                </td>

                <td>
                    <span class="display-only" id="start-label-{{ $project->id }}">{{ $project->start_date }}</span>
                    <input type="datetime-local" name="start_date" value="{{ \Carbon\Carbon::parse($project->start_date)->format('Y-m-d\TH:i') }}" class="edit-only hidden" id="start-input-{{ $project->id }}">
                </td>

                <td>
                    <span class="display-only" id="end-label-{{ $project->id }}">{{ $project->end_date }}</span>
                    <input type="datetime-local" name="end_date" value="{{ \Carbon\Carbon::parse($project->end_date)->format('Y-m-d\TH:i') }}" class="edit-only hidden" id="end-input-{{ $project->id }}">
                </td>

                <td>
                    <span class="display-only" id="creator-label-{{ $project->id }}">{{ $project->creator->name }}</span>
                    <select name="created_by" class="edit-only hidden" id="creator-input-{{ $project->id }}">
                        @foreach($users as $user)
                            <option value="{{ $user->id }}" {{ $project->created_by == $user->id ? 'selected' : '' }}>
                                {{ $user->name }}
                            </option>
                        @endforeach
                    </select>
                </td>

                <td>
                    <button type="button" onclick="enableProjectEditing('{{ $project->id }}')" class="edit-btn">Edit</button>
                    <button type="submit" class="save-btn hidden" id="save-{{ $project->id }}">Save</button>
                </td>
            </form>

            <td>
                <form action="{{ route('admin.projects.delete', $project->id) }}" method="POST" style="display:inline;">
                    @csrf
                    @method('DELETE')
                    <button type="submit" onclick="return confirm('Delete this project?')" class="delete-btn">Delete</button>
                </form>
            </td>
        </tr>
        @endforeach
    </tbody>
</table>

 </div>
</x-app-layout>
<script>
function enableProjectEditing(projectId) {
    document.getElementById(`name-label-${projectId}`).classList.add('hidden');
    document.getElementById(`slug-label-${projectId}`).classList.add('hidden');
    document.getElementById(`desc-label-${projectId}`).classList.add('hidden');
    document.getElementById(`start-label-${projectId}`).classList.add('hidden');
    document.getElementById(`end-label-${projectId}`).classList.add('hidden');
    document.getElementById(`creator-label-${projectId}`).classList.add('hidden');

    document.getElementById(`name-input-${projectId}`).classList.remove('hidden');
    document.getElementById(`slug-input-${projectId}`).classList.remove('hidden');
    document.getElementById(`desc-input-${projectId}`).classList.remove('hidden');
    document.getElementById(`start-input-${projectId}`).classList.remove('hidden');
    document.getElementById(`end-input-${projectId}`).classList.remove('hidden');
    document.getElementById(`creator-input-${projectId}`).classList.remove('hidden');

    document.getElementById(`save-${projectId}`).classList.remove('hidden');
}
</script>
