<x-app-layout>
    <x-slot name="header">Task Management Page</x-slot>

    <div class="tasks-container">
        <h1>Task List</h1>

        <div class="action-bar">
            <button onclick="document.getElementById('createForm').classList.toggle('hidden')" class="create-button">
                + Create New Task
            </button>
        </div>

        <div id="createForm" class="form-section hidden">
            <form action="{{ route('admin.tasks.store') }}" method="POST">
                @csrf
                <div class="form-grid">
                    <div class="form-group">
                        <label>Project</label>
                        <select name="project_id" required>
                            @foreach($projects as $project)
                                <option value="{{ $project->id }}">{{ $project->name }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="form-group">
                        <label>Task Title</label>
                        <input type="text" name="title" required>
                    </div>
                    <div class="form-group full-width">
                        <label>Task Description</label>
                        <textarea name="description" rows="3" required></textarea>
                    </div>
                    <div class="form-group">
                        <label>Status</label>
                        <input type="text" name="status" placeholder="e.g. pending, in-progress, completed" required>
                    </div>
                    <div class="form-group">
                        <label>Priority</label>
                        <input type="text" name="priority" placeholder="e.g. low, medium, high" required>
                    </div>
                    <div class="form-group">
                        <label>Due Date</label>
                        <input type="datetime-local" name="due_date" required>
                    </div>
                    <div class="form-group">
                        <label>Created By</label>
                        <select name="created_by" required>
                            @foreach($users as $user)
                                <option value="{{ $user->id }}">{{ $user->name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <button type="submit" class="submit-button">Create Task</button>
            </form>
        </div>

        <table class="task-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Project</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Status</th>
                    <th>Priority</th>
                    <th>Due Date</th>
                    <th>Created By</th>
                    <th>Assigned Users</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($tasks as $task)
                <form action="{{ route('admin.tasks.update', $task->id) }}" method="POST">
                    @csrf
                    @method('PUT')
                    <tr>
                        <td>{{ $task->id }}</td>
                        <td>
                            <span class="display-only" id="project-label-{{ $task->id }}">{{ $task->project->name }}</span>
                            <select name="project_id" class="edit-only hidden" id="project-input-{{ $task->id }}">
                                @foreach($projects as $project)
                                    <option value="{{ $project->id }}" {{ $task->project_id == $project->id ? 'selected' : '' }}>{{ $project->name }}</option>
                                @endforeach
                            </select>
                        </td>
                        <td>
                            <span class="display-only" id="title-label-{{ $task->id }}">{{ $task->title }}</span>
                            <input type="text" name="title" value="{{ $task->title }}" class="edit-only hidden" id="title-input-{{ $task->id }}">
                        </td>
                        <td>
                            <span class="display-only" id="desc-label-{{ $task->id }}">{{ Str::limit($task->description, 50) }}</span>
                            <textarea name="description" class="edit-only hidden" id="desc-input-{{ $task->id }}">{{ $task->description }}</textarea>
                        </td>
                        <td>
                            <span class="display-only" id="status-label-{{ $task->id }}">{{ $task->status }}</span>
                            <input type="text" name="status" value="{{ $task->status }}" class="edit-only hidden" id="status-input-{{ $task->id }}">
                        </td>
                        <td>
                            <span class="display-only" id="priority-label-{{ $task->id }}">{{ $task->priority }}</span>
                            <input type="text" name="priority" value="{{ $task->priority }}" class="edit-only hidden" id="priority-input-{{ $task->id }}">
                        </td>
                        <td>
                            <span class="display-only" id="due-label-{{ $task->id }}">{{ $task->due_date }}</span>
                            <input type="datetime-local" name="due_date" value="{{ \Carbon\Carbon::parse($task->due_date)->format('Y-m-d\TH:i') }}" class="edit-only hidden" id="due-input-{{ $task->id }}">
                        </td>
                        <td>{{ $task->creator->name }}</td>
                        <td>
                            <span class="display-only" id="assigned-label-{{ $task->id }}">
                                @if ($task->assignedUsers->isNotEmpty())
                                    @foreach ($task->assignedUsers as $user)
                                        <span>{{ $user->name }}</span><br>
                                    @endforeach
                                @else
                                    <em style="color: gray;">Not Assigned</em>
                                @endif
                            </span>
                            <select name="assigned_users[]" class="edit-only hidden" id="assigned-input-{{ $task->id }}" multiple>
                                @foreach($users as $user)
                                    <option value="{{ $user->id }}" {{ $task->assignedUsers->pluck('id')->contains($user->id) ? 'selected' : '' }}>{{ $user->name }}</option>
                                @endforeach
                            </select>
                        </td>
                        <td>
                            <button type="button" onclick="enableTaskEditing('{{ $task->id }}')" class="edit-btn">Edit</button>
                            <button type="submit" class="save-btn hidden" id="save-{{ $task->id }}">Save</button>
                </form>
                <form action="{{ route('admin.tasks.delete', $task->id) }}" method="POST" style="display:inline;">
                    @csrf
                    @method('DELETE')
                    <button type="submit" onclick="return confirm('Delete this task?')" class="delete-btn">Delete</button>
                </form>
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table>
    </div>
</x-app-layout>

<script>
function enableTaskEditing(taskId) {
    document.getElementById(`project-label-${taskId}`).classList.add('hidden');
    document.getElementById(`title-label-${taskId}`).classList.add('hidden');
    document.getElementById(`desc-label-${taskId}`).classList.add('hidden');
    document.getElementById(`status-label-${taskId}`).classList.add('hidden');
    document.getElementById(`priority-label-${taskId}`).classList.add('hidden');
    document.getElementById(`due-label-${taskId}`).classList.add('hidden');
    document.getElementById(`assigned-label-${taskId}`).classList.add('hidden');

    document.getElementById(`project-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`title-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`desc-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`status-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`priority-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`due-input-${taskId}`).classList.remove('hidden');
    document.getElementById(`assigned-input-${taskId}`).classList.remove('hidden');

    document.getElementById(`save-${taskId}`).classList.remove('hidden');
}
</script>
