<?php
use App\Http\Controllers\AdminUserController;
use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\ProjectController;
use App\Http\Controllers\TaskController;
use App\Http\Controllers\UserController;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    if(Auth::check()){
        return Auth::user()->role->name==='admin'
        ? redirect()->route('admin.dashboard')
        : redirect()->route('user.dashboard');
    }
    return redirect()->route('login');
});



Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    Route::middleware('auth')->prefix('user')->group(function () {
    Route::get('/dashboard', [UserController::class, 'dashboard'])->name('user.dashboard');
    Route::get('/tasks', [UserController::class, 'assignedTasks'])->name('user.tasks');
    Route::post('/tasks/{task}/upload', [UserController::class, 'uploadFile'])->name('user.upload');

});

});



    Route::middleware('auth')->prefix('admin')->group(function () {
    Route::get('/dashboard', function() {
        if(Auth::user()->role->name !== 'admin') {
            return redirect()->route('user.dashboard');
        }
        return view('admin.dashboard');
    })->name('admin.dashboard');
    
    Route::get('/users', [AdminUserController::class, 'index'])->name('admin.users');
    Route::post('/users', [AdminUserController::class, 'store'])->name('admin.users.store');
    Route::put('/users/{user}', [AdminUserController::class, 'update'])->name('admin.users.update');
    Route::delete('/users/{user}', [AdminUserController::class, 'delete'])->name('admin.users.delete');
    Route::get('projects', [ProjectController::class, 'index'])->name('admin.projects');
    Route::post('projects', [ProjectController::class, 'store'])->name('admin.projects.store');
    Route::put('/admin/projects/{id}', [ProjectController::class, 'update'])->name('admin.projects.update');
    Route::delete('/admin/projects/{id}', [ProjectController::class, 'delete'])->name('admin.projects.delete');
    Route::get('tasks', [TaskController::class, 'index'])->name('admin.tasks');
    Route::post('tasks', [TaskController::class, 'store'])->name('admin.tasks.store');
    Route::post('tasks/{task}/assign', [TaskController::class, 'assignUsers'])->name('admin.tasks.assign');
    Route::put('/admin/tasks/{id}', [TaskController::class, 'update'])->name('admin.tasks.update');
    Route::delete('/admin/tasks/{id}', [TaskController::class, 'delete'])->name('admin.tasks.delete');

    Route::get('/tasks/list', [TaskController::class, 'taskList'])->name('admin.tasks.list');

});

require __DIR__.'/auth.php';
